# Copyright 2019 The KerasTuner Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: keras_tuner/protos/keras_tuner.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="keras_tuner/protos/keras_tuner.proto",
    package="keras_tuner",
    syntax="proto3",
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n$keras_tuner/protos/keras_tuner.proto\x12\x0bkeras_tuner"l\n\x05Value\x12\x13\n\tint_value\x18\x01 \x01(\x12H\x00\x12\x15\n\x0b\x66loat_value\x18\x02 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x03 \x01(\tH\x00\x12\x17\n\rboolean_value\x18\x04 \x01(\x08H\x00\x42\x06\n\x04kind"\xaf\x01\n\x05\x46loat\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tmin_value\x18\x02 \x01(\x01\x12\x11\n\tmax_value\x18\x03 \x01(\x01\x12\x0c\n\x04step\x18\x04 \x01(\x01\x12\'\n\x08sampling\x18\x05 \x01(\x0e\x32\x15.keras_tuner.Sampling\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x06 \x01(\x01\x12*\n\nconditions\x18\x07 \x03(\x0b\x32\x16.keras_tuner.Condition"\xad\x01\n\x03Int\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tmin_value\x18\x02 \x01(\x12\x12\x11\n\tmax_value\x18\x03 \x01(\x12\x12\x0c\n\x04step\x18\x04 \x01(\x12\x12\'\n\x08sampling\x18\x05 \x01(\x0e\x32\x15.keras_tuner.Sampling\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x06 \x01(\x12\x12*\n\nconditions\x18\x07 \x03(\x0b\x32\x16.keras_tuner.Condition"\x9c\x01\n\x06\x43hoice\x12\x0c\n\x04name\x18\x01 \x01(\t\x12"\n\x06values\x18\x02 \x03(\x0b\x32\x12.keras_tuner.Value\x12#\n\x07\x64\x65\x66\x61ult\x18\x03 \x01(\x0b\x32\x12.keras_tuner.Value\x12\x0f\n\x07ordered\x18\x04 \x01(\x08\x12*\n\nconditions\x18\x05 \x03(\x0b\x32\x16.keras_tuner.Condition"T\n\x07\x42oolean\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x02 \x01(\x08\x12*\n\nconditions\x18\x03 \x03(\x0b\x32\x16.keras_tuner.Condition"d\n\x05\x46ixed\x12\x0c\n\x04name\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.keras_tuner.Value\x12*\n\nconditions\x18\x03 \x03(\x0b\x32\x16.keras_tuner.Condition"\xe1\x03\n\x0fHyperParameters\x12\x31\n\x05space\x18\x01 \x01(\x0b\x32".keras_tuner.HyperParameters.Space\x12\x33\n\x06values\x18\x02 \x01(\x0b\x32#.keras_tuner.HyperParameters.Values\x1a\xd6\x01\n\x05Space\x12\'\n\x0b\x66loat_space\x18\x01 \x03(\x0b\x32\x12.keras_tuner.Float\x12#\n\tint_space\x18\x02 \x03(\x0b\x32\x10.keras_tuner.Int\x12)\n\x0c\x63hoice_space\x18\x03 \x03(\x0b\x32\x13.keras_tuner.Choice\x12+\n\rboolean_space\x18\x04 \x03(\x0b\x32\x14.keras_tuner.Boolean\x12\'\n\x0b\x66ixed_space\x18\x05 \x03(\x0b\x32\x12.keras_tuner.Fixed\x1a\x8c\x01\n\x06Values\x12?\n\x06values\x18\x01 \x03(\x0b\x32/.keras_tuner.HyperParameters.Values.ValuesEntry\x1a\x41\n\x0bValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.keras_tuner.Value:\x02\x38\x01"0\n\x11MetricObservation\x12\r\n\x05value\x18\x01 \x03(\x02\x12\x0c\n\x04step\x18\x02 \x01(\x03"W\n\rMetricHistory\x12\x34\n\x0cobservations\x18\x01 \x03(\x0b\x32\x1e.keras_tuner.MetricObservation\x12\x10\n\x08maximize\x18\x02 \x01(\x08"\x97\x01\n\x0eMetricsTracker\x12\x39\n\x07metrics\x18\x01 \x03(\x0b\x32(.keras_tuner.MetricsTracker.MetricsEntry\x1aJ\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.keras_tuner.MetricHistory:\x02\x38\x01"\xf7\x01\n\x05Trial\x12\x35\n\x0fhyperparameters\x18\x01 \x01(\x0b\x32\x1c.keras_tuner.HyperParameters\x12\x10\n\x08trial_id\x18\x02 \x01(\t\x12(\n\x06status\x18\x03 \x01(\x0e\x32\x18.keras_tuner.TrialStatus\x12,\n\x07metrics\x18\x04 \x01(\x0b\x32\x1b.keras_tuner.MetricsTracker\x12\'\n\x05score\x18\x05 \x01(\x0b\x32\x18.keras_tuner.Trial.Score\x1a$\n\x05Score\x12\r\n\x05value\x18\x01 \x01(\x02\x12\x0c\n\x04step\x18\x02 \x01(\x03"\x80\x01\n\tCondition\x12/\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.keras_tuner.Condition.ParentH\x00\x1a:\n\x06Parent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12"\n\x06values\x18\x02 \x03(\x0b\x32\x12.keras_tuner.ValueB\x06\n\x04kind*:\n\x08Sampling\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06LINEAR\x10\x01\x12\x07\n\x03LOG\x10\x02\x12\x0f\n\x0bREVERSE_LOG\x10\x03*f\n\x0bTrialStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\x08\n\x04IDLE\x10\x02\x12\x0b\n\x07INVALID\x10\x03\x12\x0b\n\x07STOPPED\x10\x04\x12\r\n\tCOMPLETED\x10\x05\x12\n\n\x06\x46\x41ILED\x10\x06\x62\x06proto3',
)

_SAMPLING = _descriptor.EnumDescriptor(
    name="Sampling",
    full_name="keras_tuner.Sampling",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="NONE",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="LINEAR",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="LOG",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="REVERSE_LOG",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2022,
    serialized_end=2080,
)
_sym_db.RegisterEnumDescriptor(_SAMPLING)

Sampling = enum_type_wrapper.EnumTypeWrapper(_SAMPLING)
_TRIALSTATUS = _descriptor.EnumDescriptor(
    name="TrialStatus",
    full_name="keras_tuner.TrialStatus",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="UNKNOWN",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="RUNNING",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="IDLE",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="INVALID",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="STOPPED",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="COMPLETED",
            index=5,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="FAILED",
            index=6,
            number=6,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2082,
    serialized_end=2184,
)
_sym_db.RegisterEnumDescriptor(_TRIALSTATUS)

TrialStatus = enum_type_wrapper.EnumTypeWrapper(_TRIALSTATUS)
NONE = 0
LINEAR = 1
LOG = 2
REVERSE_LOG = 3
UNKNOWN = 0
RUNNING = 1
IDLE = 2
INVALID = 3
STOPPED = 4
COMPLETED = 5
FAILED = 6


_VALUE = _descriptor.Descriptor(
    name="Value",
    full_name="keras_tuner.Value",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="int_value",
            full_name="keras_tuner.Value.int_value",
            index=0,
            number=1,
            type=18,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="float_value",
            full_name="keras_tuner.Value.float_value",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="string_value",
            full_name="keras_tuner.Value.string_value",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="boolean_value",
            full_name="keras_tuner.Value.boolean_value",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="kind",
            full_name="keras_tuner.Value.kind",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=53,
    serialized_end=161,
)


_FLOAT = _descriptor.Descriptor(
    name="Float",
    full_name="keras_tuner.Float",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="keras_tuner.Float.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="min_value",
            full_name="keras_tuner.Float.min_value",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="max_value",
            full_name="keras_tuner.Float.max_value",
            index=2,
            number=3,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="step",
            full_name="keras_tuner.Float.step",
            index=3,
            number=4,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="sampling",
            full_name="keras_tuner.Float.sampling",
            index=4,
            number=5,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="default",
            full_name="keras_tuner.Float.default",
            index=5,
            number=6,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="conditions",
            full_name="keras_tuner.Float.conditions",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=164,
    serialized_end=339,
)


_INT = _descriptor.Descriptor(
    name="Int",
    full_name="keras_tuner.Int",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="keras_tuner.Int.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="min_value",
            full_name="keras_tuner.Int.min_value",
            index=1,
            number=2,
            type=18,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="max_value",
            full_name="keras_tuner.Int.max_value",
            index=2,
            number=3,
            type=18,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="step",
            full_name="keras_tuner.Int.step",
            index=3,
            number=4,
            type=18,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="sampling",
            full_name="keras_tuner.Int.sampling",
            index=4,
            number=5,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="default",
            full_name="keras_tuner.Int.default",
            index=5,
            number=6,
            type=18,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="conditions",
            full_name="keras_tuner.Int.conditions",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=342,
    serialized_end=515,
)


_CHOICE = _descriptor.Descriptor(
    name="Choice",
    full_name="keras_tuner.Choice",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="keras_tuner.Choice.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="values",
            full_name="keras_tuner.Choice.values",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="default",
            full_name="keras_tuner.Choice.default",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ordered",
            full_name="keras_tuner.Choice.ordered",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="conditions",
            full_name="keras_tuner.Choice.conditions",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=518,
    serialized_end=674,
)


_BOOLEAN = _descriptor.Descriptor(
    name="Boolean",
    full_name="keras_tuner.Boolean",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="keras_tuner.Boolean.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="default",
            full_name="keras_tuner.Boolean.default",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="conditions",
            full_name="keras_tuner.Boolean.conditions",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=676,
    serialized_end=760,
)


_FIXED = _descriptor.Descriptor(
    name="Fixed",
    full_name="keras_tuner.Fixed",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="keras_tuner.Fixed.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="keras_tuner.Fixed.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="conditions",
            full_name="keras_tuner.Fixed.conditions",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=762,
    serialized_end=862,
)


_HYPERPARAMETERS_SPACE = _descriptor.Descriptor(
    name="Space",
    full_name="keras_tuner.HyperParameters.Space",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="float_space",
            full_name="keras_tuner.HyperParameters.Space.float_space",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="int_space",
            full_name="keras_tuner.HyperParameters.Space.int_space",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="choice_space",
            full_name="keras_tuner.HyperParameters.Space.choice_space",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="boolean_space",
            full_name="keras_tuner.HyperParameters.Space.boolean_space",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="fixed_space",
            full_name="keras_tuner.HyperParameters.Space.fixed_space",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=989,
    serialized_end=1203,
)

_HYPERPARAMETERS_VALUES_VALUESENTRY = _descriptor.Descriptor(
    name="ValuesEntry",
    full_name="keras_tuner.HyperParameters.Values.ValuesEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="keras_tuner.HyperParameters.Values.ValuesEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="keras_tuner.HyperParameters.Values.ValuesEntry.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1281,
    serialized_end=1346,
)

_HYPERPARAMETERS_VALUES = _descriptor.Descriptor(
    name="Values",
    full_name="keras_tuner.HyperParameters.Values",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="values",
            full_name="keras_tuner.HyperParameters.Values.values",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _HYPERPARAMETERS_VALUES_VALUESENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1206,
    serialized_end=1346,
)

_HYPERPARAMETERS = _descriptor.Descriptor(
    name="HyperParameters",
    full_name="keras_tuner.HyperParameters",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="space",
            full_name="keras_tuner.HyperParameters.space",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="values",
            full_name="keras_tuner.HyperParameters.values",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _HYPERPARAMETERS_SPACE,
        _HYPERPARAMETERS_VALUES,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=865,
    serialized_end=1346,
)


_METRICOBSERVATION = _descriptor.Descriptor(
    name="MetricObservation",
    full_name="keras_tuner.MetricObservation",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="value",
            full_name="keras_tuner.MetricObservation.value",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="step",
            full_name="keras_tuner.MetricObservation.step",
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1348,
    serialized_end=1396,
)


_METRICHISTORY = _descriptor.Descriptor(
    name="MetricHistory",
    full_name="keras_tuner.MetricHistory",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="observations",
            full_name="keras_tuner.MetricHistory.observations",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="maximize",
            full_name="keras_tuner.MetricHistory.maximize",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1398,
    serialized_end=1485,
)


_METRICSTRACKER_METRICSENTRY = _descriptor.Descriptor(
    name="MetricsEntry",
    full_name="keras_tuner.MetricsTracker.MetricsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="keras_tuner.MetricsTracker.MetricsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="keras_tuner.MetricsTracker.MetricsEntry.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1565,
    serialized_end=1639,
)

_METRICSTRACKER = _descriptor.Descriptor(
    name="MetricsTracker",
    full_name="keras_tuner.MetricsTracker",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="metrics",
            full_name="keras_tuner.MetricsTracker.metrics",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _METRICSTRACKER_METRICSENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1488,
    serialized_end=1639,
)


_TRIAL_SCORE = _descriptor.Descriptor(
    name="Score",
    full_name="keras_tuner.Trial.Score",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="value",
            full_name="keras_tuner.Trial.Score.value",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="step",
            full_name="keras_tuner.Trial.Score.step",
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1853,
    serialized_end=1889,
)

_TRIAL = _descriptor.Descriptor(
    name="Trial",
    full_name="keras_tuner.Trial",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="hyperparameters",
            full_name="keras_tuner.Trial.hyperparameters",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="trial_id",
            full_name="keras_tuner.Trial.trial_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="status",
            full_name="keras_tuner.Trial.status",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="metrics",
            full_name="keras_tuner.Trial.metrics",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="score",
            full_name="keras_tuner.Trial.score",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _TRIAL_SCORE,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1642,
    serialized_end=1889,
)


_CONDITION_PARENT = _descriptor.Descriptor(
    name="Parent",
    full_name="keras_tuner.Condition.Parent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="keras_tuner.Condition.Parent.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="values",
            full_name="keras_tuner.Condition.Parent.values",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1954,
    serialized_end=2012,
)

_CONDITION = _descriptor.Descriptor(
    name="Condition",
    full_name="keras_tuner.Condition",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="keras_tuner.Condition.parent",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _CONDITION_PARENT,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="kind",
            full_name="keras_tuner.Condition.kind",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=1892,
    serialized_end=2020,
)

_VALUE.oneofs_by_name["kind"].fields.append(_VALUE.fields_by_name["int_value"])
_VALUE.fields_by_name["int_value"].containing_oneof = _VALUE.oneofs_by_name[
    "kind"
]
_VALUE.oneofs_by_name["kind"].fields.append(
    _VALUE.fields_by_name["float_value"]
)
_VALUE.fields_by_name["float_value"].containing_oneof = _VALUE.oneofs_by_name[
    "kind"
]
_VALUE.oneofs_by_name["kind"].fields.append(
    _VALUE.fields_by_name["string_value"]
)
_VALUE.fields_by_name["string_value"].containing_oneof = _VALUE.oneofs_by_name[
    "kind"
]
_VALUE.oneofs_by_name["kind"].fields.append(
    _VALUE.fields_by_name["boolean_value"]
)
_VALUE.fields_by_name["boolean_value"].containing_oneof = _VALUE.oneofs_by_name[
    "kind"
]
_FLOAT.fields_by_name["sampling"].enum_type = _SAMPLING
_FLOAT.fields_by_name["conditions"].message_type = _CONDITION
_INT.fields_by_name["sampling"].enum_type = _SAMPLING
_INT.fields_by_name["conditions"].message_type = _CONDITION
_CHOICE.fields_by_name["values"].message_type = _VALUE
_CHOICE.fields_by_name["default"].message_type = _VALUE
_CHOICE.fields_by_name["conditions"].message_type = _CONDITION
_BOOLEAN.fields_by_name["conditions"].message_type = _CONDITION
_FIXED.fields_by_name["value"].message_type = _VALUE
_FIXED.fields_by_name["conditions"].message_type = _CONDITION
_HYPERPARAMETERS_SPACE.fields_by_name["float_space"].message_type = _FLOAT
_HYPERPARAMETERS_SPACE.fields_by_name["int_space"].message_type = _INT
_HYPERPARAMETERS_SPACE.fields_by_name["choice_space"].message_type = _CHOICE
_HYPERPARAMETERS_SPACE.fields_by_name["boolean_space"].message_type = _BOOLEAN
_HYPERPARAMETERS_SPACE.fields_by_name["fixed_space"].message_type = _FIXED
_HYPERPARAMETERS_SPACE.containing_type = _HYPERPARAMETERS
_HYPERPARAMETERS_VALUES_VALUESENTRY.fields_by_name[
    "value"
].message_type = _VALUE
_HYPERPARAMETERS_VALUES_VALUESENTRY.containing_type = _HYPERPARAMETERS_VALUES
_HYPERPARAMETERS_VALUES.fields_by_name[
    "values"
].message_type = _HYPERPARAMETERS_VALUES_VALUESENTRY
_HYPERPARAMETERS_VALUES.containing_type = _HYPERPARAMETERS
_HYPERPARAMETERS.fields_by_name["space"].message_type = _HYPERPARAMETERS_SPACE
_HYPERPARAMETERS.fields_by_name["values"].message_type = _HYPERPARAMETERS_VALUES
_METRICHISTORY.fields_by_name["observations"].message_type = _METRICOBSERVATION
_METRICSTRACKER_METRICSENTRY.fields_by_name[
    "value"
].message_type = _METRICHISTORY
_METRICSTRACKER_METRICSENTRY.containing_type = _METRICSTRACKER
_METRICSTRACKER.fields_by_name[
    "metrics"
].message_type = _METRICSTRACKER_METRICSENTRY
_TRIAL_SCORE.containing_type = _TRIAL
_TRIAL.fields_by_name["hyperparameters"].message_type = _HYPERPARAMETERS
_TRIAL.fields_by_name["status"].enum_type = _TRIALSTATUS
_TRIAL.fields_by_name["metrics"].message_type = _METRICSTRACKER
_TRIAL.fields_by_name["score"].message_type = _TRIAL_SCORE
_CONDITION_PARENT.fields_by_name["values"].message_type = _VALUE
_CONDITION_PARENT.containing_type = _CONDITION
_CONDITION.fields_by_name["parent"].message_type = _CONDITION_PARENT
_CONDITION.oneofs_by_name["kind"].fields.append(
    _CONDITION.fields_by_name["parent"]
)
_CONDITION.fields_by_name[
    "parent"
].containing_oneof = _CONDITION.oneofs_by_name["kind"]
DESCRIPTOR.message_types_by_name["Value"] = _VALUE
DESCRIPTOR.message_types_by_name["Float"] = _FLOAT
DESCRIPTOR.message_types_by_name["Int"] = _INT
DESCRIPTOR.message_types_by_name["Choice"] = _CHOICE
DESCRIPTOR.message_types_by_name["Boolean"] = _BOOLEAN
DESCRIPTOR.message_types_by_name["Fixed"] = _FIXED
DESCRIPTOR.message_types_by_name["HyperParameters"] = _HYPERPARAMETERS
DESCRIPTOR.message_types_by_name["MetricObservation"] = _METRICOBSERVATION
DESCRIPTOR.message_types_by_name["MetricHistory"] = _METRICHISTORY
DESCRIPTOR.message_types_by_name["MetricsTracker"] = _METRICSTRACKER
DESCRIPTOR.message_types_by_name["Trial"] = _TRIAL
DESCRIPTOR.message_types_by_name["Condition"] = _CONDITION
DESCRIPTOR.enum_types_by_name["Sampling"] = _SAMPLING
DESCRIPTOR.enum_types_by_name["TrialStatus"] = _TRIALSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Value = _reflection.GeneratedProtocolMessageType(
    "Value",
    (_message.Message,),
    {
        "DESCRIPTOR": _VALUE,
        "__module__": "keras_tuner.protos.keras_tuner_pb2"
        # @@protoc_insertion_point(class_scope:keras_tuner.Value)
    },
)
_sym_db.RegisterMessage(Value)

Float = _reflection.GeneratedProtocolMessageType(
    "Float",
    (_message.Message,),
    {
        "DESCRIPTOR": _FLOAT,
        "__module__": "keras_tuner.protos.keras_tuner_pb2"
        # @@protoc_insertion_point(class_scope:keras_tuner.Float)
    },
)
_sym_db.RegisterMessage(Float)

Int = _reflection.GeneratedProtocolMessageType(
    "Int",
    (_message.Message,),
    {
        "DESCRIPTOR": _INT,
        "__module__": "keras_tuner.protos.keras_tuner_pb2"
        # @@protoc_insertion_point(class_scope:keras_tuner.Int)
    },
)
_sym_db.RegisterMessage(Int)

Choice = _reflection.GeneratedProtocolMessageType(
    "Choice",
    (_message.Message,),
    {
        "DESCRIPTOR": _CHOICE,
        "__module__": "keras_tuner.protos.keras_tuner_pb2"
        # @@protoc_insertion_point(class_scope:keras_tuner.Choice)
    },
)
_sym_db.RegisterMessage(Choice)

Boolean = _reflection.GeneratedProtocolMessageType(
    "Boolean",
    (_message.Message,),
    {
        "DESCRIPTOR": _BOOLEAN,
        "__module__": "keras_tuner.protos.keras_tuner_pb2"
        # @@protoc_insertion_point(class_scope:keras_tuner.Boolean)
    },
)
_sym_db.RegisterMessage(Boolean)

Fixed = _reflection.GeneratedProtocolMessageType(
    "Fixed",
    (_message.Message,),
    {
        "DESCRIPTOR": _FIXED,
        "__module__": "keras_tuner.protos.keras_tuner_pb2"
        # @@protoc_insertion_point(class_scope:keras_tuner.Fixed)
    },
)
_sym_db.RegisterMessage(Fixed)

HyperParameters = _reflection.GeneratedProtocolMessageType(
    "HyperParameters",
    (_message.Message,),
    {
        "Space": _reflection.GeneratedProtocolMessageType(
            "Space",
            (_message.Message,),
            {
                "DESCRIPTOR": _HYPERPARAMETERS_SPACE,
                "__module__": "keras_tuner.protos.keras_tuner_pb2"
                # @@protoc_insertion_point(class_scope:keras_tuner.HyperParameters.Space)
            },
        ),
        "Values": _reflection.GeneratedProtocolMessageType(
            "Values",
            (_message.Message,),
            {
                "ValuesEntry": _reflection.GeneratedProtocolMessageType(
                    "ValuesEntry",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _HYPERPARAMETERS_VALUES_VALUESENTRY,
                        "__module__": "keras_tuner.protos.keras_tuner_pb2"
                        # @@protoc_insertion_point(class_scope:keras_tuner.HyperParameters.Values.ValuesEntry)
                    },
                ),
                "DESCRIPTOR": _HYPERPARAMETERS_VALUES,
                "__module__": "keras_tuner.protos.keras_tuner_pb2"
                # @@protoc_insertion_point(class_scope:keras_tuner.HyperParameters.Values)
            },
        ),
        "DESCRIPTOR": _HYPERPARAMETERS,
        "__module__": "keras_tuner.protos.keras_tuner_pb2"
        # @@protoc_insertion_point(class_scope:keras_tuner.HyperParameters)
    },
)
_sym_db.RegisterMessage(HyperParameters)
_sym_db.RegisterMessage(HyperParameters.Space)
_sym_db.RegisterMessage(HyperParameters.Values)
_sym_db.RegisterMessage(HyperParameters.Values.ValuesEntry)

MetricObservation = _reflection.GeneratedProtocolMessageType(
    "MetricObservation",
    (_message.Message,),
    {
        "DESCRIPTOR": _METRICOBSERVATION,
        "__module__": "keras_tuner.protos.keras_tuner_pb2"
        # @@protoc_insertion_point(class_scope:keras_tuner.MetricObservation)
    },
)
_sym_db.RegisterMessage(MetricObservation)

MetricHistory = _reflection.GeneratedProtocolMessageType(
    "MetricHistory",
    (_message.Message,),
    {
        "DESCRIPTOR": _METRICHISTORY,
        "__module__": "keras_tuner.protos.keras_tuner_pb2"
        # @@protoc_insertion_point(class_scope:keras_tuner.MetricHistory)
    },
)
_sym_db.RegisterMessage(MetricHistory)

MetricsTracker = _reflection.GeneratedProtocolMessageType(
    "MetricsTracker",
    (_message.Message,),
    {
        "MetricsEntry": _reflection.GeneratedProtocolMessageType(
            "MetricsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _METRICSTRACKER_METRICSENTRY,
                "__module__": "keras_tuner.protos.keras_tuner_pb2"
                # @@protoc_insertion_point(class_scope:keras_tuner.MetricsTracker.MetricsEntry)
            },
        ),
        "DESCRIPTOR": _METRICSTRACKER,
        "__module__": "keras_tuner.protos.keras_tuner_pb2"
        # @@protoc_insertion_point(class_scope:keras_tuner.MetricsTracker)
    },
)
_sym_db.RegisterMessage(MetricsTracker)
_sym_db.RegisterMessage(MetricsTracker.MetricsEntry)

Trial = _reflection.GeneratedProtocolMessageType(
    "Trial",
    (_message.Message,),
    {
        "Score": _reflection.GeneratedProtocolMessageType(
            "Score",
            (_message.Message,),
            {
                "DESCRIPTOR": _TRIAL_SCORE,
                "__module__": "keras_tuner.protos.keras_tuner_pb2"
                # @@protoc_insertion_point(class_scope:keras_tuner.Trial.Score)
            },
        ),
        "DESCRIPTOR": _TRIAL,
        "__module__": "keras_tuner.protos.keras_tuner_pb2"
        # @@protoc_insertion_point(class_scope:keras_tuner.Trial)
    },
)
_sym_db.RegisterMessage(Trial)
_sym_db.RegisterMessage(Trial.Score)

Condition = _reflection.GeneratedProtocolMessageType(
    "Condition",
    (_message.Message,),
    {
        "Parent": _reflection.GeneratedProtocolMessageType(
            "Parent",
            (_message.Message,),
            {
                "DESCRIPTOR": _CONDITION_PARENT,
                "__module__": "keras_tuner.protos.keras_tuner_pb2"
                # @@protoc_insertion_point(class_scope:keras_tuner.Condition.Parent)
            },
        ),
        "DESCRIPTOR": _CONDITION,
        "__module__": "keras_tuner.protos.keras_tuner_pb2"
        # @@protoc_insertion_point(class_scope:keras_tuner.Condition)
    },
)
_sym_db.RegisterMessage(Condition)
_sym_db.RegisterMessage(Condition.Parent)


_HYPERPARAMETERS_VALUES_VALUESENTRY._options = None
_METRICSTRACKER_METRICSENTRY._options = None
# @@protoc_insertion_point(module_scope)
